#
# spec file for package owncloud-dolphin
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_ver 6.1.0
%define qt6_ver 6.5.0
Name:           owncloud-dolphin
Version:        6.0.0
Release:        1.1
Summary:        Dolphin Integrations for the ownCloud desktop syncing client
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Other
URL:            https://github.com/owncloud/client-desktop-shell-integration-dolphin
Source0:        %{url}/archive/refs/tags/v%{version}.tar.gz
BuildRequires:  cmake >= 2.8.11
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  kf6-extra-cmake-modules >= 6.0.0
BuildRequires:  owncloud-extensions-resources
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF6Bookmarks) >= %{kf6_ver}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_ver}
BuildRequires:  cmake(KF6KIO) >= %{kf6_ver}
BuildRequires:  cmake(Qt6Core) >= %{qt6_ver}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_ver}
BuildRequires:  cmake(Qt6Network) >= %{qt6_ver}
Requires:       owncloud-extensions-resources
Provides:       owncloud-client-dolphin = %{version}
Obsoletes:      owncloud-client-dolphin < %{version}

%description

This package provides shell integration for the ownCloud desktop sync client for KDE dolphin.

%prep
%autosetup -n client-desktop-shell-integration-dolphin-%{version}

%build
%cmake_kf6
%{kf6_build}

%install
%{kf6_install} -C build

%ldconfig_scriptlets

%check
%ctest

%files
%{_libdir}/libownclouddolphinpluginhelper.so
%dir %{_libdir}/qt6/plugins/kf6/kfileitemaction
%{_libdir}/qt6/plugins/kf6/kfileitemaction/ownclouddolphinactionplugin.so
%dir %{_libdir}/qt6/plugins/kf6/overlayicon
%{_libdir}/qt6/plugins/kf6/overlayicon/ownclouddolphinoverlayplugin.so
%{_libdir}/qt6/plugins/ownclouddolphinactionplugin.so
%doc README.md
%license COPYING

%changelog
* Mon Jan 27 2025 Christian Tallner <chrtall@gmx.de>
- Added package dependency on owncloud-extensions-resources
* Mon Jan 27 2025 Christian Tallner <chrtall@gmx.de>
- Updated to 6.0.0
- Changes since 5.0.0:
  * Set a project version
  * Cleanup
  * Depend on the icons to be present
  * Use a tumbleweed container in Ubuntu for CI to build with KF6
  * Different split code to satisfy review
  * Use pragma once consistently and add license header
  * Fix workflow description: Use Ubu 24.04 and use KF6
  * Update README
  * Cleanups, fixed the json.in
  * Port to KF6, splitting a header for the action plugin
* Wed Jan  3 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Don't self-obsolete
- Run spec-cleaner
* Wed Jan  3 2024 Klaas Freitag <opensuse@freisturz.de>
- More feedback from review. Fixed license in spec file.
* Tue Jan  2 2024 Klaas Freitag <opensuse@freisturz.de>
- Remove build requires for qt6, does not make sense
- Add obsoletes and provides for the old dolphin package
* Tue Jan  2 2024 Klaas Freitag <opensuse@freisturz.de>
- First separate package of the dolphin shell integrations for the
  ownCloud desktop syncing client. It provides overlay icons and
  an action menu.
  Since it changes much less frequent than the client it got moved
  to its own tarball.
